pub enum CapsuleError {
UnexpectedEnd,
InvalidUtf8,
MessageTooLong,
UnknownType(VarInt),
VarInt(VarIntUnexpectedEnd),
Io(Arc<Error>),
}Expand description
Errors returned by capsule encoding and decoding.
Variants
UnexpectedEnd
Input ended before the full capsule payload could be read.
InvalidUtf8
CLOSE_WEBTRANSPORT_SESSION reason bytes were not valid UTF-8.
MessageTooLong
Capsule payload exceeded the implementation message limit.
UnknownType(VarInt)
Capsule type is unsupported by this implementation.
VarInt(VarIntUnexpectedEnd)
Failed to decode a QUIC variable-length integer.
Io(Arc<Error>)
I/O error while reading from or writing to a stream.