pub enum SettingsError {
UnexpectedEnd,
UnexpectedStreamType(UniStream),
UnexpectedFrame(Frame),
InvalidSize,
Io(Arc<Error>),
}Expand description
Errors returned while encoding or decoding SETTINGS exchanges.
Variants
UnexpectedEnd
Input ended before a full SETTINGS payload was available.
UnexpectedStreamType(UniStream)
First unidirectional stream type was not the expected control stream.
UnexpectedFrame(Frame)
Frame type was not SETTINGS.
InvalidSize
Invalid varint or truncated settings pair inside a frame payload.
Io(Arc<Error>)
I/O error while reading or writing the SETTINGS exchange.