UniStream

Struct UniStream 

pub struct UniStream(pub VarInt);
Sent as the leading bytes on a unidirectional stream to indicate its stream type.

Tuple Fields

0: VarInt

Implementations

Source

impl UniStream

pub const CONTROL: UniStream

HTTP/3 control stream type.

pub const PUSH: UniStream

HTTP/3 push stream type.

pub const QPACK_ENCODER: UniStream

HTTP/3 QPACK encoder stream type.

pub const QPACK_DECODER: UniStream

HTTP/3 QPACK decoder stream type.

pub const WEBTRANSPORT: UniStream

WebTransport unidirectional stream type.

pub fn decode<B: Buf>(buf: &mut B) -> Result<Self, VarIntUnexpectedEnd>

Decode a unidirectional stream type identifier.

pub fn encode<B: BufMut>(&self, buf: &mut B)

Encode this unidirectional stream type identifier.

pub fn is_grease(&self) -> bool

Return true when this type uses RFC 9114 GREASE spacing.

pub const fn from_u32(value: u32) -> Self

Build a unidirectional stream type from a known u32 value.